==> web-audio-engine-0.12.0.tgz: package/lib/api/ConstantSourceNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioNode = require("./AudioNode");
var AudioParam = require("./AudioParam");

var ConstantSourceNode = function (_AudioNode) {
  _inherits(ConstantSourceNode, _AudioNode);

  function ConstantSourceNode(context, opts) {
    _classCallCheck(this, ConstantSourceNode);

    var _this = _possibleConstructorReturn(this, (ConstantSourceNode.__proto__ || Object.getPrototypeOf(ConstantSourceNode)).call(this, context));

    _this._impl = new impl.ConstantSourceNode(context._impl, opts);
    _this._impl.$offset = new AudioParam(context, _this._impl.getOffset());
    _this._impl.$onended = null;
    return _this;
  }

  _createClass(ConstantSourceNode, [{
    key: "start",
    value: function start(when) {
      this._impl.start(when);
    }
  }, {
    key: "stop",
    value: function stop(when) {
      this._impl.stop(when);
    }
  }, {
    key: "offset",
    get: function get() {
      return this._impl.$offset;
    }
  }, {
    key: "onended",
    get: function get() {
      return this._impl.$onended;
    },
    set: function set(callback) {
      this._impl.replaceEventListener("ended", this._impl.$onended, callback);
      this._impl.$onended = callback;
    }
  }]);

  return ConstantSourceNode;
}(AudioNode);

module.exports = ConstantSourceNode;

==> web-audio-engine-0.13.1.tgz: package/lib/api/ConstantSourceNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioScheduledSourceNode = require("./AudioScheduledSourceNode");
var AudioParam = require("./AudioParam");

var ConstantSourceNode = function (_AudioScheduledSource) {
  _inherits(ConstantSourceNode, _AudioScheduledSource);

  function ConstantSourceNode(context, opts) {
    _classCallCheck(this, ConstantSourceNode);

    var _this = _possibleConstructorReturn(this, (ConstantSourceNode.__proto__ || Object.getPrototypeOf(ConstantSourceNode)).call(this, context));

    _this._impl = new impl.ConstantSourceNode(context._impl, opts);
    _this._impl.$offset = new AudioParam(context, _this._impl.getOffset());
    _this._impl.$onended = null;
    return _this;
  }

  _createClass(ConstantSourceNode, [{
    key: "offset",
    get: function get() {
      return this._impl.$offset;
    }
  }]);

  return ConstantSourceNode;
}(AudioScheduledSourceNode);

module.exports = ConstantSourceNode;
